country = {
        "Afghanistan": "252",
        "Aland Island": "401",
        "Albania": "081",
        "Algeria": "131",
        "Andorra": "082",
        "Angola": "151",
        "Anguilla": "620",
        "Antigua And Barbuda": "621",
        "Argentina": "703",
        "Armenia": "049",
        "Aruba": "658",
        "Australia": "305",
        "Austria": "011",
        "Azerbaijan": "050",
        "Bahamas": "622",
        "Bahrain": "253",
        "Bailwick of Jersey": "412",
        "Bangladesh": "212",
        "Barbados": "610",
        "Belarus": "051",
        "Belgium": "012",
        "Belize": "541",
        "Benin": "160",
        "Bermuda": "601",
        "Bhutan": "254",
        "Bolivia": "751",
        "Bonaire, Sint Eustatius, Saba": "402",
        "Bosnia and Herzegovina": "048",
        "Botswana": "153",
        "Bouvet Island": "403",
        "Brazil": "709",
        "British Indian Ocean Territory": "404",
        "British Virgin Islands": "633",
        "Brunei Darussalam": "255",
        "Bulgaria": "083",
        "Burkina Faso": "188",
        "Burma (Myanmar)": "241",
        "Burundi": "154",
        "Cabo Verde": "911",
        "Cambodia": "256",
        "Cameroon": "155",
        "Canada": "511",
        "Canary Islands": "039",
        "Cayman Islands": "624",
        "Central African Republic": "157",
        "Chad": "156",
        "Channel Islands": "009",
        "Chile": "721",
        "China": "202",
        "China (Hong Kong SAR)": "200",
        "China (Macao SAR)": "198",
        "Christmas Island": "405",
        "Colombia": "722",
        "Comoros": "905",
        "Cook Islands": "840",
        "Costa Rica": "542",
        "Croatia": "043",
        "Cuba": "650",
        "Cura\u00e7ao": "406",
        "Cyprus": "221",
        "Czech Republic": "015",
        "Czechoslovakia": "014",
        "Democratic Rep. of Congo": "158",
        "Denmark": "017",
        "Djibouti": "183",
        "Dominica": "625",
        "Dominican Republic": "651",
        "East Timor": "916",
        "Ecuador": "753",
        "Egypt": "101",
        "El Salvador": "543",
        "England": "002",
        "Equatorial Guinea": "178",
        "Eritrea": "162",
        "Estonia": "018",
        "Ethiopia": "161",
        "Falkland Islands": "912",
        "Faroe Islands": "408",
        "Federated States of Micronesia": "835",
        "Fiji": "801",
        "Finland": "021",
        "Fr. South. and Antarctic Lands": "821",
        "France": "022",
        "French Guiana": "754",
        "French Polynesia": "845",
        "Gabon": "163",
        "Gambia": "164",
        "Georgia": "052",
        "Germany, Federal Republic Of": "024",
        "Ghana": "165",
        "Gibraltar": "084",
        "Greece": "025",
        "Greenland": "521",
        "Grenada": "626",
        "Guadeloupe": "653",
        "Guam": "832",
        "Guatemala": "544",
        "Guernsey": "409",
        "Guinea": "166",
        "Guinea-Bissau": "167",
        "Guyana": "711",
        "Haiti": "654",
        "Heard and MacDonald Islands": "410",
        "Honduras": "545",
        "Hong Kong": "204",
        "Hungary": "026",
        "Iceland": "085",
        "India": "205",
        "Indonesia": "222",
        "Iran": "223",
        "Iraq": "224",
        "Ireland": "027",
        "Isle of Man": "411",
        "Israel": "206",
        "Italy": "028",
        "Ivory Coast": "169",
        "Jamaica": "602",
        "Japan": "207",
        "Jordan": "225",
        "Kampuchea Democratic Rep.": "211",
        "Kazakhstan": "053",
        "Kenya": "132",
        "Kiribati": "831",
        "Korea, North (DPRK)": "257",
        "Korea, South": "258",
        "Kosovo": "064",
        "Kuwait": "226",
        "Kyrgyzstan": "054",
        "Laos": "260",
        "Latvia": "019",
        "Lebanon": "208",
        "Lesotho": "152",
        "Liberia": "170",
        "Libya": "171",
        "Liechtenstein": "086",
        "Lithuania": "020",
        "Luxembourg": "013",
        "Macao": "261",
        "Macedonia": "070",
        "Madagascar": "172",
        "Madeira": "036",
        "Malawi": "111",
        "Malaysia": "242",
        "Maldives": "901",
        "Mali": "173",
        "Malta": "030",
        "Marshall Islands": "834",
        "Martinique": "655",
        "Mauritania": "174",
        "Mauritius": "902",
        "Mayotte": "906",
        "Mexico": "501",
        "Moldova": "055",
        "Monaco": "087",
        "Mongolia": "262",
        "Montenegro": "063",
        "Montserrat": "627",
        "Morocco": "133",
        "Mozambique": "175",
        "Namibia": "122",
        "Nauru": "341",
        "Nepal": "264",
        "Netherlands Antilles, The": "652",
        "Netherlands, The": "031",
        "Nevis": "628",
        "New Caledonia": "822",
        "New Zealand": "339",
        "Nicaragua": "546",
        "Niger": "176",
        "Nigeria": "177",
        "Niue": "414",
        "Northern Ireland": "006",
        "Northern Mariana Islands": "830",
        "Norway": "032",
        "Oman": "263",
        "Pakistan": "209",
        "Palestinian Authority": "213",
        "Panama": "547",
        "Papua New Guinea": "342",
        "Paraguay": "755",
        "Peru": "723",
        "Philippines": "227",
        "Pitcairn Islands": "842",
        "Poland": "033",
        "Portugal": "034",
        "Puerto Rico": "656",
        "Qatar": "265",
        "Republic of Congo": "159",
        "Republic of Palau": "836",
        "R\u00e9union": "903",
        "Romania": "088",
        "Russia": "056",
        "Rwanda": "179",
        "Saint Helena": "915",
        "Saint Kitts and Nevis": "629",
        "Saint Lucia": "630",
        "Saint Pierre and Miquelon": "531",
        "Saint-Barthelemy": "407",
        "Saint-Martin": "415",
        "Samoa": "844",
        "Samoa, American": "843",
        "San Marino": "089",
        "Sao Tome and Principe": "914",
        "Saudi Arabia": "231",
        "Scotland": "007",
        "Senegal": "180",
        "Serbia And Montenegro": "061",
        "Serbia, Republic Of": "062",
        "Seychelles": "904",
        "Sierra Leone": "181",
        "Singapore": "246",
        "Sint-Maarten": "416",
        "Slovakia": "016",
        "Slovenia": "047",
        "Solomon Islands": "824",
        "Somalia": "182",
        "South Africa, Republic Of": "121",
        "South Sudan": "189",
        "Spain": "037",
        "Sri Lanka": "201",
        "St. Vincent and the Grenadines": "631",
        "Sudan": "185",
        "Suriname": "752",
        "Swaziland": "186",
        "Sweden": "040",
        "Switzerland": "041",
        "Syria": "210",
        "Taiwan": "203",
        "Tajikistan": "057",
        "Tanzania": "130",
        "Thailand": "267",
        "Tibet (Autonomous Region)": "268",
        "Togo": "187",
        "Tokelau": "417",
        "Tonga": "846",
        "Trinidad and Tobago": "605",
        "Tunisia": "135",
        "Turkey": "045",
        "Turkmenistan": "058",
        "Turks and Caicos Islands": "632",
        "Tuvalu": "826",
        "U.S. Minor outlying Islands": "418",
        "Uganda": "136",
        "Ukraine": "059",
        "Union Of Soviet Socialist Rep": "042",
        "United Arab Emirates": "280",
        "United States of America": "461",
        "Unknown": "000",
        "Uruguay": "724",
        "Uzbekistan": "060",
        "Vanuatu": "823",
        "Vatican City State": "090",
        "Venezuela": "725",
        "Vietnam": "270",
        "Virgin Islands, U.S.": "657",
        "Wales": "008",
        "Wallis and Futuna Is., Terr.": "841",
        "Western Sahara": "184",
        "Yemen": "273",
        "Yugoslavia": "044",
        "Zambia": "112",
        "Zimbabwe": "113"
    } # total 262
