# Here define all errors and prompts in different language
error_dict={
    'none is not an allowed value':"不允许为空",
    'invalid date format':'日期格式错误，必须是这种格式： 2022-01-31',
    'file':'文件中的',
    'sheet':'表',
    'the_column':'该列',
    'has error':"有错误",
    'error':'错误',
    'detail':"详细信息"
}
